// Copyright 2011 The Go Authors. All rights reserved.
// Use of this source code is governed by a BSD-style
// license that can be found in the LICENSE file.

enum {
	thechar = '6',
	BigEndian = 0,
	CacheLineSize = 64,
	RuntimeGogoBytes = 64,
	PCQuantum = 1
};
